@@ -105,7 +105,7 @@ def logout():
 @click.option('--query', '-q')
 def list_projects(query):
     """ Browse through all available projects """
-    url = '{}/acorn/create/view/project'.format(ACORN)
+    url = '{}/acorn/create/project'.format(ACORN)
     params = {}
     if query:
         params['$search'] = query
@@ -133,7 +133,7 @@ def list_projects(query):
             if token:
                 params['$skiptoken'] = token
                 click.pause('press any key for next page ...'.rjust(80))
-                url = '{}/acorn/create/view/project?$skiptoken={}'.format(ACORN, token)
+                url = '{}/acorn/create/project?$skiptoken={}'.format(ACORN, token)
             else:
                 break
 
@@ -162,7 +162,7 @@ def generate_project(project, path, version, branch, vscode, force_project, runt
     
     with load_session() as session:
         click.echo('fetching metadata...\t', nl=False)
-        r = session.get('{}/acorn/create/context/project?project_id={}'.format(ACORN, projectid))
+        r = session.get('{}/acorn/create/project/{}'.format(ACORN, projectid))
         if not r.ok:
             sys.exit('[FAIL] unable to download metadata')
         click.echo('[OK]')
@@ -206,7 +206,7 @@ def generate_project(project, path, version, branch, vscode, force_project, runt
             params['runtime'] = runtime
 
         r = session.get(
-            '{}/acorn/create/context/project/{}/view/development'.format(ACORN, projectid),
+            '{}/acorn/create/project/{}/development'.format(ACORN, projectid),
             params=params)
         if r.status_code == 404:
             sys.exit('[FAIL] {} error: requested artifact not found'.format(r.status_code))
@@ -298,7 +298,7 @@ def generate_client(project, path, version, branch, runtime, merge):
     
     with load_session() as session:
         click.echo('fetching metadata...\t', nl=False)
-        r = session.get('{}/acorn/create/context/project?project_id={}'.format(ACORN, projectid))
+        r = session.get('{}/acorn/create/project/{}'.format(ACORN, projectid))
         if not r.ok:
             sys.exit('[FAIL] unable to download metadata')
         click.echo('[OK]')
@@ -328,7 +328,7 @@ def generate_client(project, path, version, branch, runtime, merge):
             params['runtime'] = runtime
 
         r = session.get(
-            '{}/acorn/create/context/project/{}/view/development'.format(ACORN, projectid),
+            '{}/acorn/create/project/{}/development'.format(ACORN, projectid),
             params=params)
         if r.status_code == 404:
             sys.exit('[FAIL] {} error: requested artifact not found'.format(r.status_code))
@@ -438,7 +438,7 @@ def generate_target(project, token, path, version, branch, name, no_metadata, me
             params['name'] = name
 
         r = session.get(
-            '{}/acorn/consumer/context/module/{}/view/generate'.format(
+            '{}/acorn/consumer/module/{}/generate'.format(
                 ACORN,
                 quote(project)),
             params=params)
